tiled.queries.Specs
===================

.. currentmodule:: tiled.queries

.. autoclass:: Specs

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Specs.__init__
      ~Specs.decode
      ~Specs.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Specs.include
      ~Specs.exclude
   
   